<?php

define('FILETYPE_GIF', 1);
define('FILETYPE_JPG', 2);
define('FILETYPE_PNG', 3);

if (!function_exists("getShopBasePath")) {
    /**
     * Returns shop base path.
     *
     * @return string
     */
    function getShopBasePath()
    {
        return dirname(__FILE__) . '/../../../../';
    }
}

/** @var $oModule oxmodule */
$oModule = oxNew('oxmodule');
$oModule->load('d3watermark');

if ($oModule->isActive()) {
    /**
     * @return d3watermark
     */
    function d3GetWatermarkHandler()
    {
        $oWMHandler = d3watermark::getInstance();

        return $oWMHandler;
    }

    /**
     * required, because gif image generator don't call "copyAlteredImage" method
     *
     * @param $sSrc
     * @param $sTarget
     * @param $iNewWidth
     * @param $iNewHeight
     * @param $iOriginalWidth
     * @param $iOriginalHeigth
     * @param $iGDVer
     *
     * @return bool
     */
    function resizeGif($sSrc, $sTarget, $iNewWidth, $iNewHeight, $iOriginalWidth, $iOriginalHeigth, $iGDVer)
    {
        $rDestinationImage = imagecreate($iNewWidth, $iNewHeight);
        $rSourceImage      = imagecreatefromgif($sSrc);
        $iTransparentColor = imagecolorresolve($rSourceImage, 255, 255, 255);
        $iFillColor        = imagecolorresolve($rDestinationImage, 255, 255, 255);
        imagefill($rDestinationImage, 0, 0, $iFillColor);
        imagecolortransparent($rSourceImage, $iTransparentColor);

        $rSourceImage = d3GetWatermarkHandler()->d3AddWatermark($rSourceImage, $sTarget);

        if ($iGDVer == 1) {
            imagecopyresized(
                $rDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $iOriginalWidth,
                $iOriginalHeigth
            );
        } else {
            imagecopyresampled(
                $rDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $iOriginalWidth,
                $iOriginalHeigth
            );
        }

        imagecolortransparent($rDestinationImage, $iFillColor);
        imagegif($rDestinationImage, $sTarget);
        imagedestroy($rDestinationImage);
        imagedestroy($rSourceImage);

        return true;
    }

    /**
     * @param $sDestinationImage
     * @param $rSourceImage
     * @param $iNewWidth
     * @param $iNewHeight
     * @param $aImageInfo
     * @param $sTarget
     * @param $iGDVersion
     *
     * @return bool
     */
    function copyAlteredImage($sDestinationImage, $rSourceImage, $iNewWidth, $iNewHeight, $aImageInfo, $sTarget, $iGDVersion)
    {
        d3GetWatermarkHandler()->setImageInfo($aImageInfo);
        d3GetWatermarkHandler()->setGDVersion($iGDVersion);

        $rSourceImage = d3GetWatermarkHandler()->d3AddWatermark($rSourceImage, $sTarget);

        if ($iGDVersion == 1) {
            $blSuccess = imagecopyresized(
                $sDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $aImageInfo[0],
                $aImageInfo[1]
            );
        } else {
            $blSuccess = imagecopyresampled(
                $sDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $aImageInfo[0],
                $aImageInfo[1]
            );
        }

        return $blSuccess;
    }

    /**
     * @param $sSrc
     * @param $sTarget
     * @param $iWidth
     * @param $iHeight
     * @param $iOrigWidth
     * @param $iOrigHeigth
     *
     * @return array
     */
    function checkSizeAndCopy($sSrc, $sTarget, $iWidth, $iHeight, $iOrigWidth, $iOrigHeigth)
    {
        list($iNewWidth, $iNewHeight) = calcImageSize($iWidth, $iHeight, $iOrigWidth, $iOrigHeigth);

        return array($iNewWidth, $iNewHeight);
    }
}

$sPath = getShopBasePath() . "core/utils/oxpicgenerator.php";
include_once $sPath;